#ifndef DEFINITIONS_H
#define DEFINITIONS_H

//! Enum for backgroundmodes
enum backgroundModes { defaultBackground, backgroundFromTheme, backgroundFromImage, backgroundFromColor };

const QString remotesPath = "/home/user/MyDocs/qtirreco/Remotes/";
const QString qtirrecoImage = "/home/user/.qtirreco/themes/default/bg/qtirreco/irreco_logo.png";
const QString devicesPath = "/home/user/MyDocs/qtirreco/Devices/";
const QString remotesConf = "/home/user/MyDocs/qtirreco/Remotes/remotes.conf";
const QString lircpathsConf = "/home/user/MyDocs/qtirreco/lirchpaths.conf";
const QString themesPath = "/home/user/MyDocs/qtirreco/.themes/";
const QString defaultButtonsPath = "/home/user/.qtirreco/themes/default/buttons/";


#endif // DEFINITIONS_H
